<template>
  <a-card
    :bordered="false"
    title=""
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="统计时间">
              <a-range-picker
                style="width: 100%;"
                format="YYYY-MM-DD"
                v-model="faultTime"
                @change="timeChange"
              />
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="统一标码">
              <a-input
                placeholder="请输入统一标码"
                v-model="queryParam.equipmentNum"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="使用单位">
              <j-dict-select-tag
                allow-clear
                placeholder='请选择使用单位'
                :triggerChange='true'
                dictCode="mom_base_area,name,id,del_flag!='1' and type='1'"
                v-model='queryParam.workCenterId'
              />
            </a-form-item>
          </a-col>

        </a-row>
        <a-row :gutter="24">
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item
              label="关键设备标识"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <j-dict-select-tag
                allow-clear
                :triggerChange="true"
                placeholder="请选择关键设备标识"
                dictCode="specific_equipment"
                v-model="queryParam.specificEquipment"
              />
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item
              label="ABC标识"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <j-dict-select-tag
                allow-clear
                placeholder="请选择ABC标识"
                :triggerChange="true"
                dictCode="ABC-standard-result"
                v-model="queryParam.equipmentImportanceId"
              />
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <div>
      <!-- <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div> -->

      <a-table
        ref="table"
        size="middle"
        :scroll="{x:true}"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        @change="handleTableChange"
      >
        <!-- :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}" -->

      </a-table>
    </div>

  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import moment from 'moment'

export default {
  name: 'MTBF',
  mixins: [JeecgListMixin, mixinDevice],
  components: {},
  data() {
    return {
      description: 'MTBF',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '使用单位',
          align: "center",
          dataIndex: 'workCenterName'
        },
        {
          title: '统一编号',
          align: "center",
          dataIndex: 'equipmentNum'
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName'
        },
        {
          title: '设备型号',
          align: "center",
          dataIndex: 'equipmentModel'
        },
        {
          title: '总可利用时间（h）',
          align: "center",
          dataIndex: 'totalAvailableTime'
        },
        {
          title: '无故障时间（h）',
          align: "center",
          dataIndex: 'noFaultTime'
        },
        {
          title: '故障时间（h）',
          align: "center",
          dataIndex: 'faultTime'
        },
        {
          title: '修复时间（h）',
          align: "center",
          dataIndex: 'repairTime'
        },
        {
          title: '故障次数',
          align: "center",
          dataIndex: 'faultNumber'
        },
        {
          title: 'MTTR',
          align: "center",
          dataIndex: 'mttr'
        },
        {
          title: 'MTBF',
          align: "center",
          dataIndex: 'mtbf'
        },
        {
          title: '完好率',
          align: "center",
          dataIndex: 'serviceabilityRate'
        },
        {
          title: '故障率',
          align: "center",
          dataIndex: 'startRate'
        },
      ],
      url: {
        list: "/eam/mtbf/getMTBF",
      },
      // 表头
      faultTime: [],
      queryParam: {}
    }
  },
  created() { },
  methods: {
    timeChange() {
      this.queryParam.faultStartTime = moment(this.faultTime[0]).format("YYYY-MM-DD")
      this.queryParam.faultEndTime = moment(this.faultTime[1]).format("YYYY-MM-DD")
    },

    searchQuery() {
      this.loadData(1);
    },

    searchReset() {
      this.faultTime = []
      this.queryParam = {}
      this.loadData(1);
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>